#
# spec file for package dfu-util
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dfu-util
Version:        0.11
Release:        2.9
Summary:        DFU firmware upgrade utility
License:        GPL-2.0-only
Group:          Hardware/Other
URL:            http://dfu-util.sourceforge.net
Source:         http://dfu-util.sourceforge.net/releases/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libusb-1.0) >= 1.0.0

%description
This is a host side implementation of the DFU 1.0 and DFU 1.1 specifications of
the USB forum. DFU is intended to download and upload firmware to/from devices
connected over USB. It ranges from small devices like micro-controller boards
to mobile phones.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install
install -m 755 dfuse-pack.py %{buildroot}/%{_bindir}/dfuse-pack
sed -i 's|#!/usr/bin/python|#!/usr/bin/python3|g' %{buildroot}/%{_bindir}/dfuse-pack

%files
%license COPYING
%doc AUTHORS ChangeLog DEVICES.txt README
%{_bindir}/dfu-*
%{_bindir}/dfuse-pack
%{_mandir}/man1/dfu-util.1%{?ext_man}
%{_mandir}/man1/dfu-prefix.1%{?ext_man}
%{_mandir}/man1/dfu-suffix.1%{?ext_man}

%changelog
* Fri Dec 23 2022 Frank Kunz <mailinglists@kunz-im-inter.net>
- Add dfuse-pack tool to package
* Mon Sep  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.11
  * Skip setting alternate interface when not needed
  * Only clamp transfer size on Linux
  * Quirk for GD32 leave request
  * Improve status and error messages and exit codes
  * dfuse: Process all alternate interfaces in a DfuSe file
  * dfuse-pack.py: Fix alternate settings if first is 0
* Sun Dec 27 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.10
  * New --wait option for devices to appear
  * New --devnum option to filter devices
  * Support DFU_STATE_dfuMANIFEST_WAIT_RST
  * Support large files
  * Quirks for Jabra devices
  * Quirks for OpenPICC, SIMtrace
  * Quirks for GD32VF103
  * Fix numeric argument parsing
  * Improve alternate interface index matching
  * Improve libusb error messages
  * Improve Stellaris firmware detection
  * Improve warnings and debug output
  * Update manual page
  * Manual pages for dfu-suffix and dfu-prefix
  * Usage text describes DfuSe modifiers
- Drop not longer needed patch:
  * 0001-Allow-building-against-older-libusb-without-bus-port.patch
* Tue Mar 29 2016 wk@ire.pw.edu.pl
- update to upstream version 0.9
- added a patch:
    0001-Allow-building-against-older-libusb-without-bus-port.patch
    taken from dfu-util bug tracker, to build on openSUSE 13.1 (with libusb < 1.0.16)
- some build warnings fixed
* Thu Feb 12 2015 adrian@suse.de
- update to upstream version 0.8
- using _service file to create the tarball
  * modify version and revision inside and run
    "osc service disabledrun" when updating it.
* Mon Aug  6 2012 holger+suse@freyther.de
- Upgrade to upstream version 0.6
* Wed Nov  2 2011 holger+suse@freyther.de
- Upgrade to upstream version 0.5
* Fri Jul 22 2011 holger+suse@freyther.de
- Initial version of dfu-util package
